@@ -1,13 +1,13 @@
 # Copyrights 2012-2013 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 package XML::Compile::WSS::Signature;
 use vars '$VERSION';
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 use base 'XML::Compile::WSS';
 
@@ -27,9 +27,9 @@ my $unique = $$.time;
 my @default_canon_ns = qw/ds wsu xenc SOAP-ENV/;
 my @prefixes = (dsig11 => DSIG11_NS, dsp => DSP_NS, dsigm => DSIG_MORE_NS);
 
-use Data::Dumper;
-$Data::Dumper::Indent    = 1;
-$Data::Dumper::Quotekeys = 0;
+#use Data::Dumper;
+#$Data::Dumper::Indent    = 1;
+#$Data::Dumper::Quotekeys = 0;
 
 my ($digest_algorithm, $sign_algorithm);
 {  my ($signs, $sigmns) = (DSIG_NS, DSIG_MORE_NS);
